==> openflowplugin-extension-nicira-0.8.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/FlowModCopyValueIntoFieldCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.FlowModSpec;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.copy.value.into.field._case.FlowModCopyValueIntoField;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case flow-mod-copy-value-into-field-case {
 *   container flow-mod-copy-value-into-field {
 *     leaf flow-mod-num-bits {
 *       type uint16;
 *     }
 *     leaf value {
 *       type uint16;
 *     }
 *     leaf dst-field {
 *       type uint32;
 *     }
 *     leaf dst-ofs {
 *       type uint16;
 *     }
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-copy-value-into-field-case</i>
 *
 */
public interface FlowModCopyValueIntoFieldCase
    extends
    DataObject,
    Augmentable<FlowModCopyValueIntoFieldCase>,
    FlowModSpec
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("flow-mod-copy-value-into-field-case");

    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.copy.value.into.field._case.FlowModCopyValueIntoField</code> <code>flowModCopyValueIntoField</code>, or <code>null</code> if not present
     */
    @Nullable FlowModCopyValueIntoField getFlowModCopyValueIntoField();

}

==> openflowplugin-extension-nicira-0.8.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/FlowModCopyValueIntoFieldCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.FlowModSpec;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.copy.value.into.field._case.FlowModCopyValueIntoField;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case flow-mod-copy-value-into-field-case {
 *   container flow-mod-copy-value-into-field {
 *     leaf flow-mod-num-bits {
 *       type uint16;
 *     }
 *     leaf value {
 *       type uint16;
 *     }
 *     leaf dst-field {
 *       type uint32;
 *     }
 *     leaf dst-ofs {
 *       type uint16;
 *     }
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-copy-value-into-field-case</i>
 *
 */
public interface FlowModCopyValueIntoFieldCase
    extends
    DataObject,
    Augmentable<FlowModCopyValueIntoFieldCase>,
    FlowModSpec
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("flow-mod-copy-value-into-field-case");

    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.copy.value.into.field._case.FlowModCopyValueIntoField</code> <code>flowModCopyValueIntoField</code>, or <code>null</code> if not present
     */
    @Nullable FlowModCopyValueIntoField getFlowModCopyValueIntoField();

}
